==> angular__compiler-7.0.0-rc.1.jar: META-INF/resources/webjars/angular__compiler/7.0.0-rc.1/src/render3/r3_identifiers.d.ts <==
/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
import * as o from '../output/output_ast';
export declare class Identifiers {
    static NEW_METHOD: string;
    static TRANSFORM_METHOD: string;
    static PATCH_DEPS: string;
    static namespaceHTML: o.ExternalReference;
    static namespaceMathML: o.ExternalReference;
    static namespaceSVG: o.ExternalReference;
    static element: o.ExternalReference;
    static elementStart: o.ExternalReference;
    static elementEnd: o.ExternalReference;
    static elementProperty: o.ExternalReference;
    static elementAttribute: o.ExternalReference;
    static elementClassProp: o.ExternalReference;
    static elementContainerStart: o.ExternalReference;
    static elementContainerEnd: o.ExternalReference;
    static elementStyling: o.ExternalReference;
    static elementStylingMap: o.ExternalReference;
    static elementStyleProp: o.ExternalReference;
    static elementStylingApply: o.ExternalReference;
    static containerCreate: o.ExternalReference;
    static nextContext: o.ExternalReference;
    static templateCreate: o.ExternalReference;
    static text: o.ExternalReference;
    static textBinding: o.ExternalReference;
    static bind: o.ExternalReference;
    static enableBindings: o.ExternalReference;
    static disableBindings: o.ExternalReference;
    static getCurrentView: o.ExternalReference;
    static restoreView: o.ExternalReference;
    static interpolation1: o.ExternalReference;
    static interpolation2: o.ExternalReference;
    static interpolation3: o.ExternalReference;
    static interpolation4: o.ExternalReference;
    static interpolation5: o.ExternalReference;
    static interpolation6: o.ExternalReference;
    static interpolation7: o.ExternalReference;
    static interpolation8: o.ExternalReference;
    static interpolationV: o.ExternalReference;
    static pureFunction0: o.ExternalReference;
    static pureFunction1: o.ExternalReference;
    static pureFunction2: o.ExternalReference;
    static pureFunction3: o.ExternalReference;
    static pureFunction4: o.ExternalReference;
    static pureFunction5: o.ExternalReference;
    static pureFunction6: o.ExternalReference;
    static pureFunction7: o.ExternalReference;
    static pureFunction8: o.ExternalReference;
    static pureFunctionV: o.ExternalReference;
    static pipeBind1: o.ExternalReference;
    static pipeBind2: o.ExternalReference;
    static pipeBind3: o.ExternalReference;
    static pipeBind4: o.ExternalReference;
    static pipeBindV: o.ExternalReference;
    static load: o.ExternalReference;
    static loadQueryList: o.ExternalReference;
    static pipe: o.ExternalReference;
    static projection: o.ExternalReference;
    static projectionDef: o.ExternalReference;
    static reference: o.ExternalReference;
    static inject: o.ExternalReference;
    static injectAttribute: o.ExternalReference;
    static injectRenderer2: o.ExternalReference;
    static directiveInject: o.ExternalReference;
    static templateRefExtractor: o.ExternalReference;
    static defineBase: o.ExternalReference;
    static BaseDef: o.ExternalReference;
    static defineComponent: o.ExternalReference;
    static ComponentDefWithMeta: o.ExternalReference;
    static defineDirective: o.ExternalReference;
    static DirectiveDefWithMeta: o.ExternalReference;
    static InjectorDef: o.ExternalReference;
    static defineInjector: o.ExternalReference;
    static NgModuleDefWithMeta: o.ExternalReference;
    static defineNgModule: o.ExternalReference;
    static PipeDefWithMeta: o.ExternalReference;
    static definePipe: o.ExternalReference;
    static query: o.ExternalReference;
    static queryRefresh: o.ExternalReference;
    static registerContentQuery: o.ExternalReference;
    static NgOnChangesFeature: o.ExternalReference;
    static InheritDefinitionFeature: o.ExternalReference;
    static PublicFeature: o.ExternalReference;
    static listener: o.ExternalReference;
    static getFactoryOf: o.ExternalReference;
    static getInheritedFactory: o.ExternalReference;
    static sanitizeHtml: o.ExternalReference;
    static sanitizeStyle: o.ExternalReference;
    static defaultStyleSanitizer: o.ExternalReference;
    static sanitizeResourceUrl: o.ExternalReference;
    static sanitizeScript: o.ExternalReference;
    static sanitizeUrl: o.ExternalReference;
}

==> angular__compiler-7.1.0-rc.0.jar: META-INF/resources/webjars/angular__compiler/7.1.0-rc.0/src/render3/r3_identifiers.d.ts <==
/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
import * as o from '../output/output_ast';
export declare class Identifiers {
    static NEW_METHOD: string;
    static TRANSFORM_METHOD: string;
    static PATCH_DEPS: string;
    static namespaceHTML: o.ExternalReference;
    static namespaceMathML: o.ExternalReference;
    static namespaceSVG: o.ExternalReference;
    static element: o.ExternalReference;
    static elementStart: o.ExternalReference;
    static elementEnd: o.ExternalReference;
    static elementProperty: o.ExternalReference;
    static elementAttribute: o.ExternalReference;
    static elementClassProp: o.ExternalReference;
    static elementContainerStart: o.ExternalReference;
    static elementContainerEnd: o.ExternalReference;
    static elementStyling: o.ExternalReference;
    static elementStylingMap: o.ExternalReference;
    static elementStyleProp: o.ExternalReference;
    static elementStylingApply: o.ExternalReference;
    static containerCreate: o.ExternalReference;
    static nextContext: o.ExternalReference;
    static templateCreate: o.ExternalReference;
    static text: o.ExternalReference;
    static textBinding: o.ExternalReference;
    static bind: o.ExternalReference;
    static enableBindings: o.ExternalReference;
    static disableBindings: o.ExternalReference;
    static getCurrentView: o.ExternalReference;
    static restoreView: o.ExternalReference;
    static interpolation1: o.ExternalReference;
    static interpolation2: o.ExternalReference;
    static interpolation3: o.ExternalReference;
    static interpolation4: o.ExternalReference;
    static interpolation5: o.ExternalReference;
    static interpolation6: o.ExternalReference;
    static interpolation7: o.ExternalReference;
    static interpolation8: o.ExternalReference;
    static interpolationV: o.ExternalReference;
    static pureFunction0: o.ExternalReference;
    static pureFunction1: o.ExternalReference;
    static pureFunction2: o.ExternalReference;
    static pureFunction3: o.ExternalReference;
    static pureFunction4: o.ExternalReference;
    static pureFunction5: o.ExternalReference;
    static pureFunction6: o.ExternalReference;
    static pureFunction7: o.ExternalReference;
    static pureFunction8: o.ExternalReference;
    static pureFunctionV: o.ExternalReference;
    static pipeBind1: o.ExternalReference;
    static pipeBind2: o.ExternalReference;
    static pipeBind3: o.ExternalReference;
    static pipeBind4: o.ExternalReference;
    static pipeBindV: o.ExternalReference;
    static i18nAttribute: o.ExternalReference;
    static i18nExp: o.ExternalReference;
    static i18nStart: o.ExternalReference;
    static i18nEnd: o.ExternalReference;
    static i18nApply: o.ExternalReference;
    static load: o.ExternalReference;
    static loadQueryList: o.ExternalReference;
    static pipe: o.ExternalReference;
    static projection: o.ExternalReference;
    static projectionDef: o.ExternalReference;
    static reference: o.ExternalReference;
    static inject: o.ExternalReference;
    static injectAttribute: o.ExternalReference;
    static directiveInject: o.ExternalReference;
    static templateRefExtractor: o.ExternalReference;
    static defineBase: o.ExternalReference;
    static BaseDef: o.ExternalReference;
    static defineComponent: o.ExternalReference;
    static ComponentDefWithMeta: o.ExternalReference;
    static defineDirective: o.ExternalReference;
    static DirectiveDefWithMeta: o.ExternalReference;
    static InjectorDef: o.ExternalReference;
    static defineInjector: o.ExternalReference;
    static NgModuleDefWithMeta: o.ExternalReference;
    static defineNgModule: o.ExternalReference;
    static PipeDefWithMeta: o.ExternalReference;
    static definePipe: o.ExternalReference;
    static query: o.ExternalReference;
    static queryRefresh: o.ExternalReference;
    static registerContentQuery: o.ExternalReference;
    static NgOnChangesFeature: o.ExternalReference;
    static InheritDefinitionFeature: o.ExternalReference;
    static ProvidersFeature: o.ExternalReference;
    static listener: o.ExternalReference;
    static getFactoryOf: o.ExternalReference;
    static getInheritedFactory: o.ExternalReference;
    static sanitizeHtml: o.ExternalReference;
    static sanitizeStyle: o.ExternalReference;
    static defaultStyleSanitizer: o.ExternalReference;
    static sanitizeResourceUrl: o.ExternalReference;
    static sanitizeScript: o.ExternalReference;
    static sanitizeUrl: o.ExternalReference;
}
